function [Ds, L] = rsstandard(Do)
% RSSTANDARD - Standardize a design matrix Do, so that every column has mean 0 and variance 1. Version 0.1.
%
% The syntax is
% [Ds, L] = rsstandard(Do)
%
% Arguments
% Do is the original design matrix that should be standardized.
%
% Return values
% Ds is is the standardized design matrix.
% L is the scaling matrix such that Xs=Xo*L, where Xs and Xo are obtained from Ds and Do, respectively, by adding an N by 1 column vector of ones at the left.
%
% References
% No reference needed, this is trivial.


% Copyright (C) 2015 Mikael Kurula <mkurula@abo.fi>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
% FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, see <http://www.gnu.org/licenses/>.
%
% Author: Mikael Kurula <mkurula@abo.fi>, 2015


% Check input
if nargin ~= 1 ,
    error('Try help rsscale for instructions.') ;
end

% Do some calculations
s=sqrt(var(Do))';
p=1./s;
m=mean(Do)';
ell=-m./s;
[N, k]=size(Do);
L=[ 1 ell' ; zeros(k,1) diag(p)];
Xo=[ones(N,1) Do];
Xs=Xo*L;
Ds=Xs(:,2:end);

end